Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(736)

Unified Diff: chrome/browser/ui/page_info/page_info_infobar_delegate.h

Issue 2754383004: Rename WebsiteSettings code to PageInfo. (Closed)
Patch Set: Upload missing comment fix for WebSettingsUI -> PageInfoUI. Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/page_info/page_info.cc ('k') | chrome/browser/ui/page_info/page_info_infobar_delegate.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/page_info/page_info_infobar_delegate.h
diff --git a/chrome/browser/ui/page_info/website_settings_infobar_delegate.h b/chrome/browser/ui/page_info/page_info_infobar_delegate.h
similarity index 63%
rename from chrome/browser/ui/page_info/website_settings_infobar_delegate.h
rename to chrome/browser/ui/page_info/page_info_infobar_delegate.h
index 8316f2ae328ff4fd2c83be0f1145f532f9e23f3f..8f3b3c2d473138e2abdbd5c6be12612d37d8869e 100644
--- a/chrome/browser/ui/page_info/website_settings_infobar_delegate.h
+++ b/chrome/browser/ui/page_info/page_info_infobar_delegate.h
@@ -2,28 +2,28 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_UI_PAGE_INFO_WEBSITE_SETTINGS_INFOBAR_DELEGATE_H_
-#define CHROME_BROWSER_UI_PAGE_INFO_WEBSITE_SETTINGS_INFOBAR_DELEGATE_H_
+#ifndef CHROME_BROWSER_UI_PAGE_INFO_PAGE_INFO_INFOBAR_DELEGATE_H_
+#define CHROME_BROWSER_UI_PAGE_INFO_PAGE_INFO_INFOBAR_DELEGATE_H_
#include "base/macros.h"
#include "components/infobars/core/confirm_infobar_delegate.h"
class InfoBarService;
// This class configures an infobar that is shown when the website settings UI
// is closed and the settings for one or more site permissions have been
// changed. The user is shown a message indicating that a reload of the page is
// required for the changes to take effect, and presented a button to perform
// the reload right from the infobar.
-class WebsiteSettingsInfoBarDelegate : public ConfirmInfoBarDelegate {
+class PageInfoInfoBarDelegate : public ConfirmInfoBarDelegate {
public:
// Creates a website settings infobar and delegate and adds the infobar to
// |infobar_service|.
static void Create(InfoBarService* infobar_service);
private:
- WebsiteSettingsInfoBarDelegate();
- ~WebsiteSettingsInfoBarDelegate() override;
+ PageInfoInfoBarDelegate();
+ ~PageInfoInfoBarDelegate() override;
// ConfirmInfoBarDelegate:
Type GetInfoBarType() const override;
@@ -34,7 +34,7 @@ class WebsiteSettingsInfoBarDelegate : public ConfirmInfoBarDelegate {
base::string16 GetButtonLabel(InfoBarButton button) const override;
bool Accept() override;
- DISALLOW_COPY_AND_ASSIGN(WebsiteSettingsInfoBarDelegate);
+ DISALLOW_COPY_AND_ASSIGN(PageInfoInfoBarDelegate);
};
-#endif // CHROME_BROWSER_UI_PAGE_INFO_WEBSITE_SETTINGS_INFOBAR_DELEGATE_H_
+#endif // CHROME_BROWSER_UI_PAGE_INFO_PAGE_INFO_INFOBAR_DELEGATE_H_
« no previous file with comments | « chrome/browser/ui/page_info/page_info.cc ('k') | chrome/browser/ui/page_info/page_info_infobar_delegate.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -2,28 +2,28 @@
#include "components/infobars/core/confirm_infobar_delegate.h"
class InfoBarService;
-// This class configures an infobar that is shown when the website settings UI
+// This class configures an infobar that is shown when the page info UI
// is closed and the settings for one or more site permissions have been
// changed. The user is shown a message indicating that a reload of the page is
@@ -2,28 +2,28 @@
public:
- // Creates a website settings infobar and delegate and adds the infobar to
+ // Creates a page info infobar and delegate and adds the infobar to
// |infobar_service|.
static void Create(InfoBarService* infobar_service);
This is Rietveld 408576698